@@ -11,16 +11,19 @@ def check_syntax(filename):
         try:
             proc = subprocess.Popen(args, shell=False,
                                     stdout=devnull,
-                                    stderr=subprocess.PIPE)
+                                    stderr=subprocess.PIPE,
+                                    universal_newlines=True)
         except OSError as e:
             msg = "Unable to execute 'ecpg', you likely need to install it.'"
             raise OSError(msg)
 
         proc.wait()
         if proc.returncode == 0:
+            proc.stderr.close()
             return (True, "")
         else:
             err = proc.stderr.readline()
+            proc.stderr.close()
             return (False, parse_error(err))
 
 def parse_error(error):
